==> ejc-procost-impl-3.0.0-20220316.024813-1-sources.jar: com/ejianc/business/procost/bean/SettingEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本设置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_setting")
public class SettingEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="tax_flag")
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="material_cost")
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    @TableField(value="period_rule")
    private java.lang.String periodRule; // 期间规则 0-固定日期，1-自然月
    @TableField(value="end_day")
    private java.lang.Integer endDay; // 月结束日期
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称



    // 科目明细子表
    @TableField(exist = false)
    @SubEntity(serviceName="subjectService",pidName = "settingId")
    private List<SubjectEntity> subjectDetails = new ArrayList<SubjectEntity>();

    public List<SubjectEntity> getSubjectDetails() {
        return subjectDetails;
    }

    public void setSubjectDetails(List<SubjectEntity> subjectDetails) {
        this.subjectDetails = subjectDetails;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public java.lang.String getPeriodRule() {
        return periodRule;
    }

    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public void setPeriodRule(java.lang.String periodRule) {
        this.periodRule = periodRule;
    }
    /**
     * 月结束日期
     */
    public java.lang.Integer getEndDay() {
        return endDay;
    }

    /**
     * 月结束日期
     */
    public void setEndDay(java.lang.Integer endDay) {
        this.endDay = endDay;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-procost-impl-3.0.0-20220325.014454-3-sources.jar: com/ejianc/business/procost/bean/SettingEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本设置
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_setting")
public class SettingEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="tax_flag")
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
//    @TableField(value="project_id")
//    private java.lang.Long projectId; // 项目
//    @TableField(value="project_name")
//    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="material_cost")
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    @TableField(value="period_rule")
    private java.lang.String periodRule; // 期间规则 0-固定日期，1-自然月
    @TableField(value="end_day")
    private java.lang.Integer endDay; // 月结束日期
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称



    // 科目明细子表
    @TableField(exist = false)
    @SubEntity(serviceName="subjectService",pidName = "settingId")
    private List<SubjectEntity> subjectDetails = new ArrayList<SubjectEntity>();

    public List<SubjectEntity> getSubjectDetails() {
        return subjectDetails;
    }

    public void setSubjectDetails(List<SubjectEntity> subjectDetails) {
        this.subjectDetails = subjectDetails;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
//    /**
//     * 项目
//     */
//    public java.lang.Long getProjectId() {
//        return projectId;
//    }
//
//    /**
//     * 项目
//     */
//    public void setProjectId(java.lang.Long projectId) {
//        this.projectId = projectId;
//    }
//    /**
//     * 项目名称
//     */
//    public java.lang.String getProjectName() {
//        return projectName;
//    }
//
//    /**
//     * 项目名称
//     */
//    public void setProjectName(java.lang.String projectName) {
//        this.projectName = projectName;
//    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public java.lang.String getPeriodRule() {
        return periodRule;
    }

    /**
     * 期间规则 0-固定日期，1-自然月
     */
    public void setPeriodRule(java.lang.String periodRule) {
        this.periodRule = periodRule;
    }
    /**
     * 月结束日期
     */
    public java.lang.Integer getEndDay() {
        return endDay;
    }

    /**
     * 月结束日期
     */
    public void setEndDay(java.lang.Integer endDay) {
        this.endDay = endDay;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}
